# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import common_msgs_pb2 as common__msgs__pb2
import config_msgs_pb2 as config__msgs__pb2


class ConfigStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetRefFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetRefFrame',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.Frame.FromString,
                )
        self.SetRefFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetRefFrame',
                request_serializer=config__msgs__pb2.Frame.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.SetRefFramePlanar = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetRefFramePlanar',
                request_serializer=config__msgs__pb2.PlanarFrame.SerializeToString,
                response_deserializer=config__msgs__pb2.FrameResult.FromString,
                )
        self.SetToolFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetToolFrame',
                request_serializer=config__msgs__pb2.Frame.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.SetSpeedRatio = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetSpeedRatio',
                request_serializer=config__msgs__pb2.Ratio.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.SetFTsensorFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetFTsensorFrame',
                request_serializer=config__msgs__pb2.FTsensorFrame.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetFTsensorFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetFTsensorFrame',
                request_serializer=common__msgs__pb2.Response.SerializeToString,
                response_deserializer=config__msgs__pb2.FTsensorFrame.FromString,
                )
        self.SetDIConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetDIConfigList',
                request_serializer=config__msgs__pb2.DIConfigList.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetDIConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetDIConfigList',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.DIConfigList.FromString,
                )
        self.SetDOConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetDOConfigList',
                request_serializer=config__msgs__pb2.DOConfigList.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetDOConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetDOConfigList',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.DOConfigList.FromString,
                )
        self.SetHomePosition = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetHomePosition',
                request_serializer=config__msgs__pb2.JointPos.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetHomePosition = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetHomePosition',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.JointPos.FromString,
                )
        self.SetAutoServoOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetAutoServoOff',
                request_serializer=config__msgs__pb2.AutoServoOffConfig.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetAutoServoOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetAutoServoOff',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.AutoServoOffConfig.FromString,
                )
        self.SetJointControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetJointControlGain',
                request_serializer=config__msgs__pb2.JointGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetJointControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetJointControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.JointGainSet.FromString,
                )
        self.SetTaskControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetTaskControlGain',
                request_serializer=config__msgs__pb2.TaskGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetTaskControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetTaskControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.TaskGainSet.FromString,
                )
        self.SetImpedanceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetImpedanceControlGain',
                request_serializer=config__msgs__pb2.ImpedanceGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetImpedanceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetImpedanceControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.ImpedanceGainSet.FromString,
                )
        self.SetForceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetForceControlGain',
                request_serializer=config__msgs__pb2.ForceGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetForceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetForceControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.ForceGainSet.FromString,
                )
        self.SetTestControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetTestControlGain',
                request_serializer=config__msgs__pb2.TestGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetTestControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetTestControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.TestGainSet.FromString,
                )
        self.SetCustomControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCustomControlGain',
                request_serializer=config__msgs__pb2.CustomGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCustomControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCustomControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CustomGainSet.FromString,
                )
        self.SetNewControllerTestOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetNewControllerTestOnOff',
                request_serializer=config__msgs__pb2.NewControllerTestState.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetNewControllerTestOnOffState = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetNewControllerTestOnOffState',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.NewControllerTestState.FromString,
                )
        self.SetFrictionComp = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetFrictionComp',
                request_serializer=config__msgs__pb2.FrictionCompSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetFrictionComp = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetFrictionComp',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.FrictionCompSet.FromString,
                )
        self.SetMountPos = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetMountPos',
                request_serializer=config__msgs__pb2.MountingAngles.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetMountPos = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetMountPos',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.MountingAngles.FromString,
                )
        self.SetToolProperty = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetToolProperty',
                request_serializer=config__msgs__pb2.ToolProperties.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetToolProperty = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetToolProperty',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.ToolProperties.FromString,
                )
        self.SetCollSensLevel = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollSensLevel',
                request_serializer=config__msgs__pb2.CollisionSensLevel.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCollSensLevel = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCollSensLevel',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CollisionSensLevel.FromString,
                )
        self.SetCollSensParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollSensParam',
                request_serializer=config__msgs__pb2.CollisionThresholds.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCollSensParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCollSensParam',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CollisionThresholds.FromString,
                )
        self.SetCollPolicy = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollPolicy',
                request_serializer=config__msgs__pb2.CollisionPolicy.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCollPolicy = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCollPolicy',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CollisionPolicy.FromString,
                )
        self.SetSafetyLimits = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetSafetyLimits',
                request_serializer=config__msgs__pb2.SafetyLimits.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetSafetyLimits = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetSafetyLimits',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.SafetyLimits.FromString,
                )
        self.SetSafetyStopConfig = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetSafetyStopConfig',
                request_serializer=config__msgs__pb2.SafetyStopConfig.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetSafetyStopConfig = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetSafetyStopConfig',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.SafetyStopConfig.FromString,
                )
        self.SetCollTuning = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollTuning',
                request_serializer=config__msgs__pb2.CollTuningConfig.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )


class ConfigServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetRefFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRefFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRefFramePlanar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetToolFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSpeedRatio(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetFTsensorFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFTsensorFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDIConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDIConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDOConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDOConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetHomePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHomePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAutoServoOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAutoServoOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetJointControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJointControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTaskControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetImpedanceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImpedanceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetForceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetForceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTestControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTestControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCustomControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNewControllerTestOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNewControllerTestOnOffState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetFrictionComp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFrictionComp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMountPos(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMountPos(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetToolProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetToolProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollSensLevel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollSensLevel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollSensParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollSensParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSafetyLimits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSafetyLimits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSafetyStopConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSafetyStopConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollTuning(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConfigServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetRefFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRefFrame,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.Frame.SerializeToString,
            ),
            'SetRefFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRefFrame,
                    request_deserializer=config__msgs__pb2.Frame.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'SetRefFramePlanar': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRefFramePlanar,
                    request_deserializer=config__msgs__pb2.PlanarFrame.FromString,
                    response_serializer=config__msgs__pb2.FrameResult.SerializeToString,
            ),
            'SetToolFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.SetToolFrame,
                    request_deserializer=config__msgs__pb2.Frame.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'SetSpeedRatio': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSpeedRatio,
                    request_deserializer=config__msgs__pb2.Ratio.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'SetFTsensorFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.SetFTsensorFrame,
                    request_deserializer=config__msgs__pb2.FTsensorFrame.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetFTsensorFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFTsensorFrame,
                    request_deserializer=common__msgs__pb2.Response.FromString,
                    response_serializer=config__msgs__pb2.FTsensorFrame.SerializeToString,
            ),
            'SetDIConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDIConfigList,
                    request_deserializer=config__msgs__pb2.DIConfigList.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetDIConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDIConfigList,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.DIConfigList.SerializeToString,
            ),
            'SetDOConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDOConfigList,
                    request_deserializer=config__msgs__pb2.DOConfigList.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetDOConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDOConfigList,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.DOConfigList.SerializeToString,
            ),
            'SetHomePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.SetHomePosition,
                    request_deserializer=config__msgs__pb2.JointPos.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetHomePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHomePosition,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.JointPos.SerializeToString,
            ),
            'SetAutoServoOff': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAutoServoOff,
                    request_deserializer=config__msgs__pb2.AutoServoOffConfig.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetAutoServoOff': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAutoServoOff,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.AutoServoOffConfig.SerializeToString,
            ),
            'SetJointControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetJointControlGain,
                    request_deserializer=config__msgs__pb2.JointGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetJointControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJointControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.JointGainSet.SerializeToString,
            ),
            'SetTaskControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTaskControlGain,
                    request_deserializer=config__msgs__pb2.TaskGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetTaskControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.TaskGainSet.SerializeToString,
            ),
            'SetImpedanceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetImpedanceControlGain,
                    request_deserializer=config__msgs__pb2.ImpedanceGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetImpedanceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImpedanceControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.ImpedanceGainSet.SerializeToString,
            ),
            'SetForceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetForceControlGain,
                    request_deserializer=config__msgs__pb2.ForceGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetForceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetForceControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.ForceGainSet.SerializeToString,
            ),
            'SetTestControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTestControlGain,
                    request_deserializer=config__msgs__pb2.TestGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetTestControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTestControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.TestGainSet.SerializeToString,
            ),
            'SetCustomControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCustomControlGain,
                    request_deserializer=config__msgs__pb2.CustomGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCustomControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CustomGainSet.SerializeToString,
            ),
            'SetNewControllerTestOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNewControllerTestOnOff,
                    request_deserializer=config__msgs__pb2.NewControllerTestState.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetNewControllerTestOnOffState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNewControllerTestOnOffState,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.NewControllerTestState.SerializeToString,
            ),
            'SetFrictionComp': grpc.unary_unary_rpc_method_handler(
                    servicer.SetFrictionComp,
                    request_deserializer=config__msgs__pb2.FrictionCompSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetFrictionComp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFrictionComp,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.FrictionCompSet.SerializeToString,
            ),
            'SetMountPos': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMountPos,
                    request_deserializer=config__msgs__pb2.MountingAngles.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetMountPos': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMountPos,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.MountingAngles.SerializeToString,
            ),
            'SetToolProperty': grpc.unary_unary_rpc_method_handler(
                    servicer.SetToolProperty,
                    request_deserializer=config__msgs__pb2.ToolProperties.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetToolProperty': grpc.unary_unary_rpc_method_handler(
                    servicer.GetToolProperty,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.ToolProperties.SerializeToString,
            ),
            'SetCollSensLevel': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollSensLevel,
                    request_deserializer=config__msgs__pb2.CollisionSensLevel.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCollSensLevel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollSensLevel,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CollisionSensLevel.SerializeToString,
            ),
            'SetCollSensParam': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollSensParam,
                    request_deserializer=config__msgs__pb2.CollisionThresholds.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCollSensParam': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollSensParam,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CollisionThresholds.SerializeToString,
            ),
            'SetCollPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollPolicy,
                    request_deserializer=config__msgs__pb2.CollisionPolicy.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCollPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollPolicy,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CollisionPolicy.SerializeToString,
            ),
            'SetSafetyLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSafetyLimits,
                    request_deserializer=config__msgs__pb2.SafetyLimits.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetSafetyLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSafetyLimits,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.SafetyLimits.SerializeToString,
            ),
            'SetSafetyStopConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSafetyStopConfig,
                    request_deserializer=config__msgs__pb2.SafetyStopConfig.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetSafetyStopConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSafetyStopConfig,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.SafetyStopConfig.SerializeToString,
            ),
            'SetCollTuning': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollTuning,
                    request_deserializer=config__msgs__pb2.CollTuningConfig.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Nrmk.IndyFramework.Config', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Config(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetRefFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetRefFrame',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.Frame.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRefFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetRefFrame',
            config__msgs__pb2.Frame.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRefFramePlanar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetRefFramePlanar',
            config__msgs__pb2.PlanarFrame.SerializeToString,
            config__msgs__pb2.FrameResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetToolFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetToolFrame',
            config__msgs__pb2.Frame.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSpeedRatio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetSpeedRatio',
            config__msgs__pb2.Ratio.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetFTsensorFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetFTsensorFrame',
            config__msgs__pb2.FTsensorFrame.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFTsensorFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetFTsensorFrame',
            common__msgs__pb2.Response.SerializeToString,
            config__msgs__pb2.FTsensorFrame.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDIConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetDIConfigList',
            config__msgs__pb2.DIConfigList.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDIConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetDIConfigList',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.DIConfigList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDOConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetDOConfigList',
            config__msgs__pb2.DOConfigList.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDOConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetDOConfigList',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.DOConfigList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetHomePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetHomePosition',
            config__msgs__pb2.JointPos.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHomePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetHomePosition',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.JointPos.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAutoServoOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetAutoServoOff',
            config__msgs__pb2.AutoServoOffConfig.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAutoServoOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetAutoServoOff',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.AutoServoOffConfig.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetJointControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetJointControlGain',
            config__msgs__pb2.JointGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJointControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetJointControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.JointGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTaskControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetTaskControlGain',
            config__msgs__pb2.TaskGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTaskControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetTaskControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.TaskGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetImpedanceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetImpedanceControlGain',
            config__msgs__pb2.ImpedanceGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImpedanceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetImpedanceControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.ImpedanceGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetForceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetForceControlGain',
            config__msgs__pb2.ForceGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetForceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetForceControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.ForceGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTestControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetTestControlGain',
            config__msgs__pb2.TestGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTestControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetTestControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.TestGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCustomControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCustomControlGain',
            config__msgs__pb2.CustomGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCustomControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CustomGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNewControllerTestOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetNewControllerTestOnOff',
            config__msgs__pb2.NewControllerTestState.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNewControllerTestOnOffState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetNewControllerTestOnOffState',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.NewControllerTestState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetFrictionComp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetFrictionComp',
            config__msgs__pb2.FrictionCompSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFrictionComp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetFrictionComp',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.FrictionCompSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMountPos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetMountPos',
            config__msgs__pb2.MountingAngles.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMountPos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetMountPos',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.MountingAngles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetToolProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetToolProperty',
            config__msgs__pb2.ToolProperties.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetToolProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetToolProperty',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.ToolProperties.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollSensLevel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollSensLevel',
            config__msgs__pb2.CollisionSensLevel.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollSensLevel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCollSensLevel',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CollisionSensLevel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollSensParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollSensParam',
            config__msgs__pb2.CollisionThresholds.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollSensParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCollSensParam',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CollisionThresholds.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollPolicy',
            config__msgs__pb2.CollisionPolicy.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCollPolicy',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CollisionPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSafetyLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetSafetyLimits',
            config__msgs__pb2.SafetyLimits.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSafetyLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetSafetyLimits',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.SafetyLimits.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSafetyStopConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetSafetyStopConfig',
            config__msgs__pb2.SafetyStopConfig.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSafetyStopConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetSafetyStopConfig',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.SafetyStopConfig.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollTuning(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollTuning',
            config__msgs__pb2.CollTuningConfig.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rtde_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import device_msgs_pb2 as device__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rtde_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0frtde_msgs.proto\x12\x12Nrmk.IndyFramework\x1a\x11\x64\x65vice_msgs.proto\x1a\x11\x63ommon_msgs.proto\"-\n\x0bTestRequest\x12\x0e\n\x06intVal\x18\x01 \x01(\x05\x12\x0e\n\x06strVal\x18\x02 \x01(\t\")\n\x0cTestResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\xeb\x02\n\nMotionData\x12\x31\n\ntraj_state\x18\x01 \x01(\x0e\x32\x1d.Nrmk.IndyFramework.TrajState\x12\x15\n\rtraj_progress\x18\x02 \x01(\x05\x12\x14\n\x0cis_in_motion\x18\x03 \x01(\x08\x12\x19\n\x11is_target_reached\x18\x04 \x01(\x08\x12\x12\n\nis_pausing\x18\x05 \x01(\x08\x12\x13\n\x0bis_stopping\x18\x06 \x01(\x08\x12\x12\n\nhas_motion\x18\x07 \x01(\x08\x12\x13\n\x0bspeed_ratio\x18\x08 \x01(\x05\x12\x11\n\tmotion_id\x18\t \x01(\x05\x12\x17\n\x0fremain_distance\x18\n \x01(\x02\x12\x19\n\x11motion_queue_size\x18\x0b \x01(\r\x12\x19\n\x11\x63ur_traj_progress\x18\x0c \x01(\x05\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x9a\x02\n\x0b\x43ontrolData\x12\x15\n\rrunning_hours\x18\x01 \x01(\r\x12\x14\n\x0crunning_mins\x18\x02 \x01(\r\x12\x14\n\x0crunning_secs\x18\x03 \x01(\r\x12-\n\x08op_state\x18\x04 \x01(\x0e\x32\x1b.Nrmk.IndyFramework.OpState\x12\x10\n\x08sim_mode\x18\x05 \x01(\x08\x12\t\n\x01q\x18\n \x03(\x02\x12\x0c\n\x04qdot\x18\x0b \x03(\x02\x12\t\n\x01p\x18\x0c \x03(\x02\x12\x0c\n\x04pdot\x18\r \x03(\x02\x12\x11\n\tref_frame\x18\x14 \x03(\x02\x12\x12\n\ntool_frame\x18\x15 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x9f\x02\n\x0c\x43ontrolData2\x12\t\n\x01q\x18\x01 \x03(\x02\x12\x0c\n\x04qdot\x18\x02 \x03(\x02\x12\r\n\x05qddot\x18\x03 \x03(\x02\x12\x0c\n\x04qdes\x18\x04 \x03(\x02\x12\x0f\n\x07qdotdes\x18\x05 \x03(\x02\x12\x10\n\x08qddotdes\x18\x06 \x03(\x02\x12\t\n\x01p\x18\n \x03(\x02\x12\x0c\n\x04pdot\x18\x0b \x03(\x02\x12\r\n\x05pddot\x18\x0c \x03(\x02\x12\x0c\n\x04pdes\x18\r \x03(\x02\x12\x0f\n\x07pdotdes\x18\x0e \x03(\x02\x12\x10\n\x08pddotdes\x18\x0f \x03(\x02\x12\x0b\n\x03tau\x18\x14 \x03(\x02\x12\x0f\n\x07tau_act\x18\x15 \x03(\x02\x12\x0f\n\x07tau_ext\x18\x16 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xbc\x03\n\x06IOData\x12-\n\x02\x64i\x18\x01 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12-\n\x02\x64o\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12,\n\x02\x61i\x18\x03 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12,\n\x02\x61o\x18\x04 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x31\n\x06\x65nd_di\x18\x05 \x03(\x0b\x32!.Nrmk.IndyFramework.EndtoolSignal\x12\x31\n\x06\x65nd_do\x18\x06 \x03(\x0b\x32!.Nrmk.IndyFramework.EndtoolSignal\x12\x30\n\x06\x65nd_ai\x18\x07 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x30\n\x06\x65nd_ao\x18\x08 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x9f\x01\n\rViolationData\x12\x16\n\x0eviolation_code\x18\x01 \x01(\x04\x12\x0f\n\x07j_index\x18\x02 \x01(\r\x12\x0e\n\x06i_args\x18\x03 \x03(\x05\x12\x0e\n\x06\x66_args\x18\x04 \x03(\x02\x12\x15\n\rviolation_str\x18\x05 \x01(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xb9\x01\n\tServoData\x12\x14\n\x0cstatus_codes\x18\x01 \x03(\t\x12\x14\n\x0ctemperatures\x18\x02 \x03(\x02\x12\x10\n\x08voltages\x18\x03 \x03(\x02\x12\x10\n\x08\x63urrents\x18\x04 \x03(\x02\x12\x15\n\rservo_actives\x18\n \x03(\x08\x12\x15\n\rbrake_actives\x18\x0b \x03(\x08\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xa6\x02\n\x0bProgramData\x12\x37\n\rprogram_state\x18\x01 \x01(\x0e\x32 .Nrmk.IndyFramework.ProgramState\x12\x0e\n\x06\x63md_id\x18\x02 \x01(\x05\x12\x12\n\nsub_cmd_id\x18\x03 \x01(\x05\x12\x15\n\rrunning_hours\x18\x04 \x01(\r\x12\x14\n\x0crunning_mins\x18\x05 \x01(\r\x12\x14\n\x0crunning_secs\x18\x06 \x01(\r\x12\x14\n\x0cprogram_name\x18\x07 \x01(\t\x12\x15\n\rprogram_alarm\x18\x08 \x01(\t\x12\x1a\n\x12program_annotation\x18\t \x01(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Responseb\x06proto3'
  ,
  dependencies=[device__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])




_TESTREQUEST = _descriptor.Descriptor(
  name='TestRequest',
  full_name='Nrmk.IndyFramework.TestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intVal', full_name='Nrmk.IndyFramework.TestRequest.intVal', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strVal', full_name='Nrmk.IndyFramework.TestRequest.strVal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=122,
)


_TESTRESPONSE = _descriptor.Descriptor(
  name='TestResponse',
  full_name='Nrmk.IndyFramework.TestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Nrmk.IndyFramework.TestResponse.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='Nrmk.IndyFramework.TestResponse.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=165,
)


_MOTIONDATA = _descriptor.Descriptor(
  name='MotionData',
  full_name='Nrmk.IndyFramework.MotionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traj_state', full_name='Nrmk.IndyFramework.MotionData.traj_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_progress', full_name='Nrmk.IndyFramework.MotionData.traj_progress', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_in_motion', full_name='Nrmk.IndyFramework.MotionData.is_in_motion', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_target_reached', full_name='Nrmk.IndyFramework.MotionData.is_target_reached', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_pausing', full_name='Nrmk.IndyFramework.MotionData.is_pausing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_stopping', full_name='Nrmk.IndyFramework.MotionData.is_stopping', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_motion', full_name='Nrmk.IndyFramework.MotionData.has_motion', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_ratio', full_name='Nrmk.IndyFramework.MotionData.speed_ratio', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motion_id', full_name='Nrmk.IndyFramework.MotionData.motion_id', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remain_distance', full_name='Nrmk.IndyFramework.MotionData.remain_distance', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motion_queue_size', full_name='Nrmk.IndyFramework.MotionData.motion_queue_size', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cur_traj_progress', full_name='Nrmk.IndyFramework.MotionData.cur_traj_progress', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.MotionData.response', index=12,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=531,
)


_CONTROLDATA = _descriptor.Descriptor(
  name='ControlData',
  full_name='Nrmk.IndyFramework.ControlData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='running_hours', full_name='Nrmk.IndyFramework.ControlData.running_hours', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_mins', full_name='Nrmk.IndyFramework.ControlData.running_mins', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_secs', full_name='Nrmk.IndyFramework.ControlData.running_secs', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='op_state', full_name='Nrmk.IndyFramework.ControlData.op_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sim_mode', full_name='Nrmk.IndyFramework.ControlData.sim_mode', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q', full_name='Nrmk.IndyFramework.ControlData.q', index=5,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdot', full_name='Nrmk.IndyFramework.ControlData.qdot', index=6,
      number=11, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='Nrmk.IndyFramework.ControlData.p', index=7,
      number=12, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdot', full_name='Nrmk.IndyFramework.ControlData.pdot', index=8,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_frame', full_name='Nrmk.IndyFramework.ControlData.ref_frame', index=9,
      number=20, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tool_frame', full_name='Nrmk.IndyFramework.ControlData.tool_frame', index=10,
      number=21, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ControlData.response', index=11,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=816,
)


_CONTROLDATA2 = _descriptor.Descriptor(
  name='ControlData2',
  full_name='Nrmk.IndyFramework.ControlData2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='q', full_name='Nrmk.IndyFramework.ControlData2.q', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdot', full_name='Nrmk.IndyFramework.ControlData2.qdot', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qddot', full_name='Nrmk.IndyFramework.ControlData2.qddot', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdes', full_name='Nrmk.IndyFramework.ControlData2.qdes', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdotdes', full_name='Nrmk.IndyFramework.ControlData2.qdotdes', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qddotdes', full_name='Nrmk.IndyFramework.ControlData2.qddotdes', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='Nrmk.IndyFramework.ControlData2.p', index=6,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdot', full_name='Nrmk.IndyFramework.ControlData2.pdot', index=7,
      number=11, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pddot', full_name='Nrmk.IndyFramework.ControlData2.pddot', index=8,
      number=12, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdes', full_name='Nrmk.IndyFramework.ControlData2.pdes', index=9,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdotdes', full_name='Nrmk.IndyFramework.ControlData2.pdotdes', index=10,
      number=14, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pddotdes', full_name='Nrmk.IndyFramework.ControlData2.pddotdes', index=11,
      number=15, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tau', full_name='Nrmk.IndyFramework.ControlData2.tau', index=12,
      number=20, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tau_act', full_name='Nrmk.IndyFramework.ControlData2.tau_act', index=13,
      number=21, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tau_ext', full_name='Nrmk.IndyFramework.ControlData2.tau_ext', index=14,
      number=22, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ControlData2.response', index=15,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=1106,
)


_IODATA = _descriptor.Descriptor(
  name='IOData',
  full_name='Nrmk.IndyFramework.IOData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di', full_name='Nrmk.IndyFramework.IOData.di', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do', full_name='Nrmk.IndyFramework.IOData.do', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ai', full_name='Nrmk.IndyFramework.IOData.ai', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ao', full_name='Nrmk.IndyFramework.IOData.ao', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_di', full_name='Nrmk.IndyFramework.IOData.end_di', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_do', full_name='Nrmk.IndyFramework.IOData.end_do', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_ai', full_name='Nrmk.IndyFramework.IOData.end_ai', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_ao', full_name='Nrmk.IndyFramework.IOData.end_ao', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.IOData.response', index=8,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1553,
)


_VIOLATIONDATA = _descriptor.Descriptor(
  name='ViolationData',
  full_name='Nrmk.IndyFramework.ViolationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='violation_code', full_name='Nrmk.IndyFramework.ViolationData.violation_code', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j_index', full_name='Nrmk.IndyFramework.ViolationData.j_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_args', full_name='Nrmk.IndyFramework.ViolationData.i_args', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f_args', full_name='Nrmk.IndyFramework.ViolationData.f_args', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='violation_str', full_name='Nrmk.IndyFramework.ViolationData.violation_str', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ViolationData.response', index=5,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1556,
  serialized_end=1715,
)


_SERVODATA = _descriptor.Descriptor(
  name='ServoData',
  full_name='Nrmk.IndyFramework.ServoData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_codes', full_name='Nrmk.IndyFramework.ServoData.status_codes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperatures', full_name='Nrmk.IndyFramework.ServoData.temperatures', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voltages', full_name='Nrmk.IndyFramework.ServoData.voltages', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currents', full_name='Nrmk.IndyFramework.ServoData.currents', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='servo_actives', full_name='Nrmk.IndyFramework.ServoData.servo_actives', index=4,
      number=10, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_actives', full_name='Nrmk.IndyFramework.ServoData.brake_actives', index=5,
      number=11, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ServoData.response', index=6,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1718,
  serialized_end=1903,
)


_PROGRAMDATA = _descriptor.Descriptor(
  name='ProgramData',
  full_name='Nrmk.IndyFramework.ProgramData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='program_state', full_name='Nrmk.IndyFramework.ProgramData.program_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd_id', full_name='Nrmk.IndyFramework.ProgramData.cmd_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sub_cmd_id', full_name='Nrmk.IndyFramework.ProgramData.sub_cmd_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_hours', full_name='Nrmk.IndyFramework.ProgramData.running_hours', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_mins', full_name='Nrmk.IndyFramework.ProgramData.running_mins', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_secs', full_name='Nrmk.IndyFramework.ProgramData.running_secs', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='program_name', full_name='Nrmk.IndyFramework.ProgramData.program_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='program_alarm', full_name='Nrmk.IndyFramework.ProgramData.program_alarm', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='program_annotation', full_name='Nrmk.IndyFramework.ProgramData.program_annotation', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ProgramData.response', index=9,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1906,
  serialized_end=2200,
)

_MOTIONDATA.fields_by_name['traj_state'].enum_type = common__msgs__pb2._TRAJSTATE
_MOTIONDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_CONTROLDATA.fields_by_name['op_state'].enum_type = common__msgs__pb2._OPSTATE
_CONTROLDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_CONTROLDATA2.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_IODATA.fields_by_name['di'].message_type = device__msgs__pb2._DIGITALSIGNAL
_IODATA.fields_by_name['do'].message_type = device__msgs__pb2._DIGITALSIGNAL
_IODATA.fields_by_name['ai'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['ao'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['end_di'].message_type = device__msgs__pb2._ENDTOOLSIGNAL
_IODATA.fields_by_name['end_do'].message_type = device__msgs__pb2._ENDTOOLSIGNAL
_IODATA.fields_by_name['end_ai'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['end_ao'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_VIOLATIONDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_SERVODATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_PROGRAMDATA.fields_by_name['program_state'].enum_type = common__msgs__pb2._PROGRAMSTATE
_PROGRAMDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['TestRequest'] = _TESTREQUEST
DESCRIPTOR.message_types_by_name['TestResponse'] = _TESTRESPONSE
DESCRIPTOR.message_types_by_name['MotionData'] = _MOTIONDATA
DESCRIPTOR.message_types_by_name['ControlData'] = _CONTROLDATA
DESCRIPTOR.message_types_by_name['ControlData2'] = _CONTROLDATA2
DESCRIPTOR.message_types_by_name['IOData'] = _IODATA
DESCRIPTOR.message_types_by_name['ViolationData'] = _VIOLATIONDATA
DESCRIPTOR.message_types_by_name['ServoData'] = _SERVODATA
DESCRIPTOR.message_types_by_name['ProgramData'] = _PROGRAMDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TestRequest = _reflection.GeneratedProtocolMessageType('TestRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTREQUEST,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TestRequest)
  })
_sym_db.RegisterMessage(TestRequest)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSE,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TestResponse)
  })
_sym_db.RegisterMessage(TestResponse)

MotionData = _reflection.GeneratedProtocolMessageType('MotionData', (_message.Message,), {
  'DESCRIPTOR' : _MOTIONDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MotionData)
  })
_sym_db.RegisterMessage(MotionData)

ControlData = _reflection.GeneratedProtocolMessageType('ControlData', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ControlData)
  })
_sym_db.RegisterMessage(ControlData)

ControlData2 = _reflection.GeneratedProtocolMessageType('ControlData2', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLDATA2,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ControlData2)
  })
_sym_db.RegisterMessage(ControlData2)

IOData = _reflection.GeneratedProtocolMessageType('IOData', (_message.Message,), {
  'DESCRIPTOR' : _IODATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IOData)
  })
_sym_db.RegisterMessage(IOData)

ViolationData = _reflection.GeneratedProtocolMessageType('ViolationData', (_message.Message,), {
  'DESCRIPTOR' : _VIOLATIONDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ViolationData)
  })
_sym_db.RegisterMessage(ViolationData)

ServoData = _reflection.GeneratedProtocolMessageType('ServoData', (_message.Message,), {
  'DESCRIPTOR' : _SERVODATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoData)
  })
_sym_db.RegisterMessage(ServoData)

ProgramData = _reflection.GeneratedProtocolMessageType('ProgramData', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAMDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ProgramData)
  })
_sym_db.RegisterMessage(ProgramData)


# @@protoc_insertion_point(module_scope)
